@@ -65,12 +65,13 @@ namespace gbrainy.Clients.Classical.Dialogs
 			}
 			// File selection
 			string def_file;
+			string def_dir = Environment.GetFolderPath (Environment.SpecialFolder.MyDocuments);
 			def_file = System.IO.Path.Combine (
-				Environment.GetFolderPath (Environment.SpecialFolder.MyDocuments),
+				def_dir,
 				// Translators: default file name used when exporting PDF files (keep the pdf extension please)
 				Catalog.GetString ("games.pdf"));
 
-			file = new BrowseFile (hbox_file, def_file, true);
+			file = new BrowseFile (hbox_file, def_file, def_dir);
 
 			FileFilter[] filters = new FileFilter [2];
 			filters[0] = new FileFilter ();
