@@ -45,7 +45,6 @@ namespace gbrainy.Clients.Classical
 		[Builder.Object] Gtk.Button tip_button;
 		[Builder.Object] Gtk.Button next_button;
 		[Builder.Object] Gtk.Statusbar statusbar;
-		[Builder.Object] Gtk.MenuBar menubar;
 		[Builder.Object] Gtk.MenuItem pause_menuitem;
 		[Builder.Object] Gtk.MenuItem finish_menuitem;
 		[Builder.Object] Gtk.MenuItem newgame_menuitem;
@@ -65,7 +64,6 @@ namespace gbrainy.Clients.Classical
 		GameSession session;
 		bool full_screen;
 		GameSession.Types initial_session;
-		static bool pluggins_loaded;
 
 		public readonly int MIN_TRANSLATION = 80;
 
