@@ -12,16 +12,12 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
 using System.Collections.Generic;
 
-using gbrainy.Core.Services;
-
 namespace gbrainy.Core.Main.Verbal
 {
 	public class AnalogiesPairOfWordsCompare : Analogies
@@ -38,7 +34,7 @@ namespace gbrainy.Core.Main.Verbal
 		}
 
 		public override string Name {
-			get { return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Pair of words compare #{0}"), Variant);}
+			get { return String.Format (Translations.GetString ("Pair of words compare #{0}"), Variant);}
 		}
 
 		public override Dictionary <int, Analogy> List {
@@ -53,12 +49,32 @@ namespace gbrainy.Core.Main.Verbal
 				if (Current.answers == null)
 					return Current.question;
 
-				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString (
+				return String.Format (Translations.GetString (
 					"Given the relationship between the two words below, which word has the same relationship to '{0}'?"),
 					sample);
 			}
 		}
 
+		public override string AnswerText {
+			get {
+				string str;
+				string[] items;
+
+				items = Answer.Correct.Split (AnalogiesFactory.Separator);
+
+				str = String.Format (Translations.GetPluralString ("The correct answer is {0}.",
+					"The possible correct answers are {0}.", items.Length),
+					Answer.CorrectShow);
+
+				if (String.IsNullOrEmpty (Rationale))
+					return str;
+
+				// Translators: answer + rationale of the answer
+				return String.Format (Translations.GetString ("{0} {1}"), str, Rationale);
+			}
+		}
+
+
 		protected override void Initialize ()
 		{
 			Current = GetNext ();
@@ -91,7 +107,7 @@ namespace gbrainy.Core.Main.Verbal
 
 			gr.SetPangoLargeFontSize ();
 			gr.DrawTextCentered (0.5, y + 0.25,
-				String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Words: {0}"), samples));
+				String.Format (Translations.GetString ("Words: {0}"), samples));
 		}
 	}
 }
