@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
@@ -24,6 +22,8 @@ using System.Collections.Generic;
 using System.Globalization;
 using System.Text;
 
+using gbrainy.Core.Libraries;
+
 namespace gbrainy.Core.Main.Xml
 {
 	public class GamesXmlFactory
@@ -72,6 +72,11 @@ namespace gbrainy.Core.Main.Xml
 						TextDrawingObject drawing_object = (TextDrawingObject) last_drawing_object;
 						// GetText processes msgctxt as msgctxt + context_glue + text to retrieve them
 						drawing_object.Text = last_context + CONTEXT_GLUE + text;
+
+						// If the string does not exits, return regular English string without context
+						if (GetText.StringExists (drawing_object.Text) == false)
+							drawing_object.Text = text;
+
 						continue;
 					}
 
@@ -413,6 +418,9 @@ namespace gbrainy.Core.Main.Xml
 						if (String.Compare (str, "yes", true) == 0)
 							option.Correct = true;
 
+						if (option.X + option.Width > 1 || option.Y + option.Height > 1)
+							Console.WriteLine ("GameXmlFactory. Wrong option size. x+width and y+height cannot be larger than 1");
+
 						break;
 					default:
 						if (String.IsNullOrEmpty (name) == false)
