@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
@@ -34,7 +32,7 @@ namespace gbrainy.Core.Toolkit
 		public delegate void WidgetDrawEventHandler (object sender, DrawEventArgs e);
 
 		public event EventHandler DrawRequest;
-		public event EventHandler <SeletectedEventArgs> SelectedEvent;
+		public event EventHandler <SelectedEventArgs> SelectedEvent;
 		ISynchronizeInvoke synchronize;
 		bool sensitive;
 
@@ -79,7 +77,7 @@ namespace gbrainy.Core.Toolkit
 			DrawRequest (this, EventArgs.Empty);
 		}
 
-		protected void OnSelected (SeletectedEventArgs e)
+		protected void OnSelected (SelectedEventArgs e)
 		{
 			if (SelectedEvent == null)
 				return;
