@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
@@ -55,17 +53,17 @@ namespace gbrainy.Games.Logic
 		Figure [] figure_answers;
 
 		public override string Name {
-			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Figures");}
+			get {return Translations.GetString ("Figures");}
 		}
 
 		public override string Question {
-			get {return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("What is the next logical sequence of objects in the last column? Answer {0}, {1} or {2}."),
+			get {return String.Format (Translations.GetString ("What is the next logical sequence of objects in the last column? Answer {0}, {1} or {2}."),
 				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2));}
 		}
 
 		public override string Rationale {
 			get {
-				return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("It is the only combination that you can build with the given elements without repeating them.");
+				return Translations.GetString ("It is the only combination that you can build with the given elements without repeating them.");
 			}
 		}
 
@@ -117,10 +115,6 @@ namespace gbrainy.Games.Logic
 				drawable_area.DataEx = Answer.GetMultiOption (ans);
 				container.AddChild (drawable_area);
 
-				if (answer_indices[ans] == good_answer) {
-					Answer.SetMultiOptionAnswer (ans, Answer.GetFigureName (ans));
-				}
-
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
 					double width = total_width / possible_answers;
@@ -137,6 +131,7 @@ namespace gbrainy.Games.Logic
 					e.Context.Stroke ();
 				};
 			}
+			Answer.SetMultiOptionAnswer (answer_indices[good_answer], Answer.GetFigureName (answer_indices[good_answer]));
 		}
 
 		static void DrawFigure (CairoContextEx gr, double x, double y, Figure figure)
@@ -192,7 +187,7 @@ namespace gbrainy.Games.Logic
 			}
 
 			gr.MoveTo (0.08, 0.45);
-			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
 			gr.Stroke ();
 		}
 	}
